@@ -1,19 +1,21 @@
-# -*- coding: utf-8 -*-
 from concurrent.futures import ThreadPoolExecutor
 from typing import Iterator
 
 from logzero import logger
 
 from chaoslib.activity import execute_activity
-from chaoslib.types import Configuration, Experiment, Run, Secrets
-
+from chaoslib.types import Configuration, Dry, Experiment, Run, Secrets
 
 __all__ = ["run_rollbacks"]
 
 
-def run_rollbacks(experiment: Experiment, configuration: Configuration,
-                  secrets: Secrets, pool: ThreadPoolExecutor,
-                  dry: bool = False) -> Iterator[Run]:
+def run_rollbacks(
+    experiment: Experiment,
+    configuration: Configuration,
+    secrets: Secrets,
+    pool: ThreadPoolExecutor,
+    dry: Dry,
+) -> Iterator[Run]:
     """
     Run all rollbacks declared in the experiment in their order. Wait for
     each rollback activity to complete before to the next unless the activity
@@ -29,10 +31,19 @@ def run_rollbacks(experiment: Experiment, configuration: Configuration,
 
         if activity.get("background"):
             logger.debug("rollback activity will run in the background")
-            yield pool.submit(execute_activity, experiment=experiment,
-                              activity=activity, configuration=configuration,
-                              secrets=secrets, dry=dry)
+            yield pool.submit(
+                execute_activity,
+                experiment=experiment,
+                activity=activity,
+                configuration=configuration,
+                secrets=secrets,
+                dry=dry,
+            )
         else:
-            yield execute_activity(experiment, activity,
-                                   configuration=configuration,
-                                   secrets=secrets, dry=dry)
+            yield execute_activity(
+                experiment,
+                activity,
+                configuration=configuration,
+                secrets=secrets,
+                dry=dry,
+            )
